==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1DeploymentStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface AppsV1beta1DeploymentStrategyFluent<A extends AppsV1beta1DeploymentStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1RollingUpdateDeployment getRollingUpdate();
    public AppsV1beta1RollingUpdateDeployment buildRollingUpdate();
    public A withRollingUpdate(AppsV1beta1RollingUpdateDeployment rollingUpdate);
    public Boolean hasRollingUpdate();
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(AppsV1beta1RollingUpdateDeployment item);
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(AppsV1beta1RollingUpdateDeployment item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1RollingUpdateDeploymentFluent<AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1DeploymentStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface AppsV1beta1DeploymentStrategyFluent<A extends AppsV1beta1DeploymentStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1RollingUpdateDeployment getRollingUpdate();
    public AppsV1beta1RollingUpdateDeployment buildRollingUpdate();
    public A withRollingUpdate(AppsV1beta1RollingUpdateDeployment rollingUpdate);
    public Boolean hasRollingUpdate();
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(AppsV1beta1RollingUpdateDeployment item);
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(AppsV1beta1RollingUpdateDeployment item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1RollingUpdateDeploymentFluent<AppsV1beta1DeploymentStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}
